summaryrefslogtreecommitdiffstats
path: root/kio/kfile/kencodingfiledialog.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2010-07-31 19:46:43 +0000
commitffe8a83e053396df448e9413828527613ca3bd46 (patch)
treea73d4169e02df4a50f9a12cb165fcd0ab5bac7c6 /kio/kfile/kencodingfiledialog.h
parent682bf3bfdcbcbb1fca85e8a36ed03e062e0555d5 (diff)
downloadtdelibs-ffe8a83e053396df448e9413828527613ca3bd46.tar.gz
tdelibs-ffe8a83e053396df448e9413828527613ca3bd46.zip
Trinity Qt initial conversion
git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdelibs@1157647 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kio/kfile/kencodingfiledialog.h')
-rw-r--r--kio/kfile/kencodingfiledialog.h94
1 files changed, 47 insertions, 47 deletions
diff --git a/kio/kfile/kencodingfiledialog.h b/kio/kfile/kencodingfiledialog.h
index fbf3b34e6..15b44f9c3 100644
--- a/kio/kfile/kencodingfiledialog.h
+++ b/kio/kfile/kencodingfiledialog.h
@@ -43,9 +43,9 @@ class KIO_EXPORT KEncodingFileDialog : public KFileDialog
public:
class Result {
public:
- QStringList fileNames;
+ TQStringList fileNames;
KURL::List URLs;
- QString encoding;
+ TQString encoding;
};
/**
@@ -53,7 +53,7 @@ public:
*
* @param startDir This can either be
* @li The URL of the directory to start in.
* @li QString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
* @li ':&lt;keyword&gt;' to start in the directory last used
@@ -64,7 +64,7 @@ public:
* same keyword.
*
* @param encoding The encoding shown in the encoding combo. If it's
* QString::null, the global default encoding will be shown.
*
* @param filter This is a space separated list of shell globs.
* You can set the text to be displayed for the glob, and
@@ -82,11 +82,11 @@ public:
*
* @since 3.2
*/
- KEncodingFileDialog (const QString& startDir = QString::null,
- const QString& encoding = QString::null,
- const QString& filter = QString::null,
- const QString& caption = QString::null, KFileDialog::OperationMode type = KFileDialog::Opening,
- QWidget *parent= 0, const char *name="", bool modal = true);
+ KEncodingFileDialog (const TQString& startDir = TQString::null,
+ const TQString& encoding = TQString::null,
+ const TQString& filter = TQString::null,
+ const TQString& caption = TQString::null, KFileDialog::OperationMode type = KFileDialog::Opening,
+ TQWidget *parent= 0, const char *name="", bool modal = true);
/**
* Destructs the file dialog.
*/
@@ -94,9 +94,9 @@ public:
/**
* @returns The selected encoding if the constructor with the encoding parameter was used, otherwise QString::null.
*/
- QString selectedEncoding() const;
+ TQString selectedEncoding() const;
/**
@@ -109,7 +109,7 @@ public:
*
* @param startDir This can either be
* @li The URL of the directory to start in.
* @li QString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
* @li ':&lt;keyword&gt;' to start in the directory last used
@@ -126,11 +126,11 @@ public:
* @param parent The widget the dialog will be centered on initially.
* @param caption The name of the dialog widget.
*/
- static Result getOpenFileNameAndEncoding(const QString& encoding=QString::null,
- const QString& startDir= QString::null,
- const QString& filter= QString::null,
- QWidget *parent= 0,
- const QString& caption = QString::null);
+ static Result getOpenFileNameAndEncoding(const TQString& encoding=TQString::null,
+ const TQString& startDir= TQString::null,
+ const TQString& filter= TQString::null,
+ TQWidget *parent= 0,
+ const TQString& caption = TQString::null);
/**
* Creates a modal file dialog and returns the selected encoding and the selected
@@ -141,7 +141,7 @@ public:
*
* @param startDir This can either be
* @li The URL of the directory to start in.
* @li QString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
* @li ':&lt;keyword&gt;' to start in the directory last used
@@ -158,11 +158,11 @@ public:
* @param parent The widget the dialog will be centered on initially.
* @param caption The name of the dialog widget.
*/
- static Result getOpenFileNamesAndEncoding(const QString& encoding=QString::null,
- const QString& startDir= QString::null,
- const QString& filter= QString::null,
- QWidget *parent = 0,
- const QString& caption= QString::null);
+ static Result getOpenFileNamesAndEncoding(const TQString& encoding=TQString::null,
+ const TQString& startDir= TQString::null,
+ const TQString& filter= TQString::null,
+ TQWidget *parent = 0,
+ const TQString& caption= TQString::null);
/**
* Creates a modal file dialog and returns the selected encoding and
@@ -173,7 +173,7 @@ public:
*
* @param startDir This can either be
* @li The URL of the directory to start in.
* @li QString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
* @li ':&lt;keyword&gt;' to start in the directory last used
@@ -190,11 +190,11 @@ public:
* @param parent The widget the dialog will be centered on initially.
* @param caption The name of the dialog widget.
*/
- static Result getOpenURLAndEncoding(const QString& encoding=QString::null,
- const QString& startDir = QString::null,
- const QString& filter= QString::null,
- QWidget *parent= 0,
- const QString& caption = QString::null);
+ static Result getOpenURLAndEncoding(const TQString& encoding=TQString::null,
+ const TQString& startDir = TQString::null,
+ const TQString& filter= TQString::null,
+ TQWidget *parent= 0,
+ const TQString& caption = TQString::null);
@@ -208,7 +208,7 @@ public:
*
* @param startDir This can either be
* @li The URL of the directory to start in.
* @li QString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
* @li ':&lt;keyword&gt;' to start in the directory last used
@@ -225,11 +225,11 @@ public:
* @param parent The widget the dialog will be centered on initially.
* @param caption The name of the dialog widget.
*/
- static Result getOpenURLsAndEncoding(const QString& encoding=QString::null,
- const QString& startDir= QString::null,
- const QString& filter= QString::null,
- QWidget *parent = 0,
- const QString& caption= QString::null);
+ static Result getOpenURLsAndEncoding(const TQString& encoding=TQString::null,
+ const TQString& startDir= TQString::null,
+ const TQString& filter= TQString::null,
+ TQWidget *parent = 0,
+ const TQString& caption= TQString::null);
@@ -244,7 +244,7 @@ public:
* @li The URL of the directory to start in.
* @li a relative path or a filename determining the
* directory to start in and the file to be selected.
* @li QString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
* @li ':&lt;keyword&gt;' to start in the directory last used
@@ -261,11 +261,11 @@ public:
* @param parent The widget the dialog will be centered on initially.
* @param caption The name of the dialog widget.
*/
- static Result getSaveFileNameAndEncoding(const QString& encoding=QString::null,
- const QString& startDir=QString::null,
- const QString& filter= QString::null,
- QWidget *parent= 0,
- const QString& caption = QString::null);
+ static Result getSaveFileNameAndEncoding(const TQString& encoding=TQString::null,
+ const TQString& startDir=TQString::null,
+ const TQString& filter= TQString::null,
+ TQWidget *parent= 0,
+ const TQString& caption = TQString::null);
/**
@@ -279,7 +279,7 @@ public:
* @li The URL of the directory to start in.
* @li a relative path or a filename determining the
* directory to start in and the file to be selected.
* @li QString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
* @li ':&lt;keyword&gt;' to start in the directory last used
@@ -296,11 +296,11 @@ public:
* @param parent The widget the dialog will be centered on initially.
* @param caption The name of the dialog widget.
*/
- static Result getSaveURLAndEncoding(const QString& encoding=QString::null,
- const QString& startDir= QString::null,
- const QString& filter= QString::null,
- QWidget *parent= 0,
- const QString& caption = QString::null);
+ static Result getSaveURLAndEncoding(const TQString& encoding=TQString::null,
+ const TQString& startDir= TQString::null,
+ const TQString& filter= TQString::null,
+ TQWidget *parent= 0,
+ const TQString& caption = TQString::null);
@@ -53,7 +53,7 @@ public:
* @param startDir This can either be
* @li The URL of the directory to start in.
- * @li QString::null to start in the current working
+ * @li TQString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
@@ -64,7 +64,7 @@ public:
*
* @param encoding The encoding shown in the encoding combo. If it's
- * QString::null, the global default encoding will be shown.
+ * TQString::null, the global default encoding will be shown.
*
* @param filter This is a space separated list of shell globs.
@@ -94,9 +94,9 @@ public:
/**
- * @returns The selected encoding if the constructor with the encoding parameter was used, otherwise QString::null.
+ * @returns The selected encoding if the constructor with the encoding parameter was used, otherwise TQString::null.
*/
@@ -109,7 +109,7 @@ public:
* @param startDir This can either be
* @li The URL of the directory to start in.
- * @li QString::null to start in the current working
+ * @li TQString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
@@ -141,7 +141,7 @@ public:
* @param startDir This can either be
* @li The URL of the directory to start in.
- * @li QString::null to start in the current working
+ * @li TQString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
@@ -173,7 +173,7 @@ public:
* @param startDir This can either be
* @li The URL of the directory to start in.
- * @li QString::null to start in the current working
+ * @li TQString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
@@ -208,7 +208,7 @@ public:
* @param startDir This can either be
* @li The URL of the directory to start in.
- * @li QString::null to start in the current working
+ * @li TQString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
@@ -244,7 +244,7 @@ public:
* @li a relative path or a filename determining the
* directory to start in and the file to be selected.
- * @li QString::null to start in the current working
+ * @li TQString::null to start in the current working
* directory, or the last directory where a file has been
* selected.
@@ -279,7 +279,7 @@ public:
* @li a relative path or a filename determining the
* directory to start in and the file to be selected.
- * @li QString::null to start in the current working
+ * @li TQString::null to start in the current working
* directory, or the last directory where a file has been
* selected.